<?php

namespace Drupal\field_file_and_translations\Plugin\Field\FieldType;

use Drupal\Core\Field\Attribute\FieldType;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\file\Plugin\Field\FieldType\FileFieldItemList;
use Drupal\file\Plugin\Field\FieldType\FileItem;

/**
 * Plugin implementation of the 'file_and_translations' field type.
 */
#[FieldType(
  id: "file_and_translations",
  label: new TranslatableMarkup("File and translations"),
  description: [
    new TranslatableMarkup("For uploading the original file and its translations"),
    new TranslatableMarkup("Allows a user to upload a file and translation in a batch,"),
    new TranslatableMarkup(
      "Can be configured with options such as allowed file extensions, "
    ),
  ],
  category: "file_upload",
  default_widget: "file_and_translations_widget",
  default_formatter: "file_default",
  list_class: FileFieldItemList::class,
  constraints: ["ReferenceAccess" => [], "FileValidation" => []],
  column_groups: [
    'target_id' => [
      'label' => new TranslatableMarkup('File'),
      'translatable' => TRUE,
    ],
    'display' => [
      'label' => new TranslatableMarkup('Display'),
      'translatable' => TRUE,
    ],
    'description' => [
      'label' => new TranslatableMarkup('Description'),
      'translatable' => TRUE,
    ],
  ],
)]
class FileAndTranslationsItem extends FileItem {

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return parent::schema($field_definition);
  }

}
