<?php

declare(strict_types=1);

namespace Drupal\Tests\field_file_and_translations\Functional;

ini_set('xdebug.var_display_max_depth', 10);
ini_set('xdebug.var_display_max_children', 256);
ini_set('xdebug.var_display_max_data', 1000024);


use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\field_ui\Traits\FieldUiTestTrait;

/**
 * Prueba funcional del campo 'file_and_translations' en nodos con traducciones.
 *
 * @group field_file_and_translations
 */
class FileAndTranslationNodeTest extends BrowserTestBase {

  use FieldUiTestTrait;
  use FieldFileAndTranslationsCreationTrait;

  /**
   * Los módulos que se activarán para esta prueba.
   *
   * @var array
   */
  protected static $modules = ['field_file_and_translations', 'node', 'system', 'field_ui'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with administration permissions.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer site configuration',
      'administer users',
      'administer permissions',
      'administer content types',
      'administer node fields',
      'administer node display',
      'administer nodes',
      'bypass node access',
    ]);
    $this->drupalLogin($this->adminUser);
    $this->drupalCreateContentType(['type' => 'article', 'name' => 'Article']);
    $this->enableTestingLanguages();
    $field_name = 'field_cv';
    $type_name = 'article';

    $this->createFieldFileAndTranslations($field_name, 'node', $type_name);
  }


  /**
   * Tests all filenames must have language suffix but default language.
   */
  public function testUploadingFilesFromDefaultLanguageNodeFormValidations(): void {
    $this->drupalGet('node/add/article');
    $this->getSession()->getPage()->fillField('Title', 'Article 1');

    // Uploading a file with an invalid (not enabled) language suffix.
    $this->attachFileToField('sample_xx.pdf');
    $this->submitForm([], 'Upload');

    $this->assertSession()->pageTextContains('The file name should specify a valid language code as the suffix of the file name separated by a hyphen or underscore. Example: myfile-en.pdf.');
    $this->assertSession()->pageTextContains('Only the following languages are allowed: en, it, pt, es.');

    // Uploading a file with a valid default language file (no suffix).
    $this->drupalGet('node/add/article');
    $this->getSession()->getPage()->fillField('Title', 'Article 1');

    $this->attachFileToField('sample.pdf');
    $this->submitForm([], 'Upload');

    $this->assertSession()->elementExists('xpath', '//a[contains(@href, "sample") and @type="application/pdf"]');

    // Uploading a file with a valid default language file (with default language suffix).
    $this->drupalGet('node/add/article');
    $this->getSession()->getPage()->fillField('Title', 'Article 1');

    $this->attachFileToField('sample_en.pdf');
    $this->submitForm([], 'Upload');

    $this->assertSession()->elementExists('xpath', '//a[contains(@href, "sample_en") and @type="application/pdf"]');


    // Uploading files enabled languages.
    $this->drupalGet('node/add/article');
    $this->getSession()->getPage()->fillField('Title', 'Article 1');

    $this->attachFileToField('sample_en.pdf');
    $this->submitForm([], 'Upload');

    $this->attachFileToField('sample_es.pdf');
    $this->submitForm([], 'Upload');

    $this->assertSession()->elementExists('xpath', '//a[contains(@href, "sample_en") and @type="application/pdf"]');
    $this->assertSession()->elementExists('xpath', '//a[contains(@href, "sample_es") and @type="application/pdf"]');

    // Uploading files enabled languages repeating language file.
    $this->drupalGet('node/add/article');
    $this->getSession()->getPage()->fillField('Title', 'Article 1');

    $this->attachFileToField('sample_en.pdf');
    $this->submitForm([], 'Upload');

    $this->attachFileToField('sample_es.pdf');
    $this->submitForm([], 'Upload');

    $this->attachFileToField('sample2_es.pdf');
    $this->submitForm([], 'Upload');

    $this->assertSession()->pageTextContains('You cannot upload more than one file with the same language suffix (es).');
  }

  /**
   * Tests all filenames must have language suffix but default language.
   */
  public function testUploadingFilesFromTranslationLanguageEditNodeForm(): void {

  }

  /**
   * Tests all filenames must have language suffix but default language.
   */
  public function testFilesAndTranslationDisplay(): void {

  }



}
